# Inspect: A Proteomics Search Toolkit

Copyright 2007, The Regents of the University of California

### Table of Contents
- Overview
- Copyright information
- Installation
- Database
- Searching
- Analysis
- Basic Tutorial
- Advanced Tutorial
- Unrestricted Search Tutorial

  # Installation

  To install Inspect, first unzip the source distribution. You may need to compile it:
- On Windows, use the included executable inspect.exe. You can build the source code on Windows using the makefile, or the included Visual Studio project.
- On Linux, first install expat. Then, build Inspect using the included makefile.
- Macintosh is not officially supported. Follow the instructions for Linux, they are likely to work.
  Other things to do while you're installing:
- Inspect requires Python (version 2.1 or later) in order to run various analysis and utility scripts.
- (Optional) You may wish to install the Python Imaging Library (PIL) for generation of simple spectrum images.
- (Optional) If the psyco library is installed, it is automatically loaded to speed up analysis scripts; this is entirely optional.
- (Recommended) The Python numeric library (numpy) is required for some analysis scripts.
- The distribution includes some system tests. After installing, go to the Inspect directory, and run them to be sure that things are installed properly:
  `python SystemTest.py`
  After the run completes, any errors will be reported. Files used by the system tests are stored in the "SystemTest" subdirectory. The test input file "TestInput.txt" is annotated with comments, and you can refer to it (or copy and modify it) when starting up searches.
  If the tests fail, please submit a bug report (and include any relevant-looking error messages).